/*******************************************************************
*
* DESCRIPTION: Atomic Model of livernode
*
* AUTHOR: Alexander Dias, Banan Al-Aubiydy
*
* DATE: 24 Jan,2005
*
*******************************************************************/
#include "liverNode.h" // base header
#include "message.h" // InternalMessage ....
#include "mainsimu.h" // class MainSimulator
#include "strutil.h" // str2Value(...)
#include "except.h" // class InvalidMessageException
/*******************************************************************
* Function Name: livernode
* Description: constructor
********************************************************************/
livernode::livernode( const string &name )
: Atomic( name )
, Win( addInputPort( "Win" ) )
, Wout( addOutputPort( "Wout" ) )
, preparationTime( 0, 0, 5, 0 )
, time_zero( 0, 0, 3, 0)
{
string time( MainSimulator::Instance().getParameter(
description(), "preparation" ) ) ;
if( time != "" )
preparationTime = time ;
}
/*******************************************************************
* Function Name: initFunction
********************************************************************/
Model &livernode::initFunction()
{
Value = 0;
return *this ;
}
/*******************************************************************
* Function Name: externalFunction
********************************************************************/
Model &livernode::externalFunction( const ExternalMessage &msg )
{
	if ( this->state() == passive){
//RECEIVES MESSAGES FROM Win PORT
if(msg.port() == Win)
{
//ASSIGNS INPUT TO Value
Value = msg.value();
holdIn(active,preparationTime);
cout<<"LiverNode Received: "<<Value <<" at time "<<
msg.time() <<endl;
}
}
return *this ;
}
/*******************************************************************
* Function Name: internalFunction
********************************************************************/
Model &livernode::internalFunction( const InternalMessage & )
{
passivate();
return *this;
}
/*******************************************************************
* Function Name: outputFunction
********************************************************************/
Model &livernode::outputFunction( const InternalMessage &msg )
{
//BASED ON INPUT, CHOOSE APPROPRIATE OUTPUT
if(Value==1){
Value = 1; //(NADH + H+)
}else if(Value==2){
Value = 2; //UDP
}else if(Value==3){
Value = 3; //fosfoenolpiruvato
}else if(Value==4){
Value = 4; //Fructose-6-P
}else if(Value==5){
Value = 11; //Glucose-6-P
}
//DISPLAY OUTPUT AND SEND IT TO ANY CONNECTED NODES
cout<<"LiverNode Produced: "<<Value<<" at time "<<
msg.time()<<endl;
sendOutput( msg.time(), Wout, Value );
return *this;
}